
Celery Pantry
=============

.. image:: https://readthedocs.org/projects/celery-pantry/badge/?version=latest
    :target: https://celery-pantry.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Django Rest Framework application to store and access Celery task information.

The `example_project` Django project demonstrates how to integrate `celery_pantry` into a Django project.

It can be seen in action with Docker by running::

    docker-compose up

